==> create-fly-1.21.10-6.0.8-5-sources.jar: com/zurrtum/create/client/infrastructure/model/CardboardSwordModel.java <==
package com.zurrtum.create.client.infrastructure.model;

import com.google.common.base.Suppliers;
import com.mojang.serialization.MapCodec;
import net.minecraft.class_10419;
import net.minecraft.class_10430;
import net.minecraft.class_10439;
import net.minecraft.class_10442;
import net.minecraft.class_10444;
import net.minecraft.class_10809;
import net.minecraft.class_10819;
import net.minecraft.class_1086;
import net.minecraft.class_11566;
import net.minecraft.class_1799;
import net.minecraft.class_1921;
import net.minecraft.class_2960;
import net.minecraft.class_4722;
import net.minecraft.class_638;
import net.minecraft.class_777;
import net.minecraft.class_7775;
import net.minecraft.class_811;
import net.minecraft.client.render.model.*;
import org.jetbrains.annotations.Nullable;
import org.joml.Vector3f;

import java.util.List;
import java.util.function.Supplier;

import static com.zurrtum.create.Create.MOD_ID;

public class CardboardSwordModel implements class_10439 {
    public static final class_2960 ID = class_2960.method_60655(MOD_ID, "model/cardboard_sword");
    public static final class_2960 ITEM_ID = class_2960.method_60655(MOD_ID, "item/cardboard_sword/item");
    public static final class_2960 BLOCK_ID = class_2960.method_60655(MOD_ID, "item/cardboard_sword/item_in_hand");

    private final class_1921 layer = class_4722.method_29382();
    private final List<class_777> itemQuads;
    private final Supplier<Vector3f[]> itemVector;
    private final List<class_777> blockQuads;
    private final Supplier<Vector3f[]> blockVector;
    private final class_10809 settings;

    public CardboardSwordModel(List<class_777> item, List<class_777> block, class_10809 settings) {
        itemQuads = item;
        itemVector = Suppliers.memoize(() -> class_10430.method_67990(itemQuads));
        blockQuads = block;
        blockVector = Suppliers.memoize(() -> class_10430.method_67990(blockQuads));
        this.settings = settings;
    }

    @Override
    public void method_65584(
        class_10444 state,
        class_1799 stack,
        class_10442 resolver,
        class_811 displayContext,
        @Nullable class_638 world,
        @Nullable class_11566 user,
        int seed
    ) {
        state.method_70946(this);
        if (displayContext == class_811.field_4317) {
            update(state, displayContext, itemQuads, settings, itemVector);
        } else {
            update(state, displayContext, blockQuads, settings, blockVector);
        }
    }

    private void update(
        class_10444 state,
        class_811 displayContext,
        List<class_777> quads,
        class_10809 settings,
        Supplier<Vector3f[]> vector
    ) {
        class_10444.class_10446 layerRenderState = state.method_65601();
        layerRenderState.method_67992(layer);
        layerRenderState.method_67995(vector);
        settings.method_68000(layerRenderState, displayContext);
        layerRenderState.method_67997().addAll(quads);
    }

    public static class Unbaked implements class_10439.class_10441 {
        public static final MapCodec<Unbaked> CODEC = MapCodec.unit(Unbaked::new);

        @Override
        public MapCodec<Unbaked> method_65585() {
            return CODEC;
        }

        @Override
        public void method_62326(class_10103 resolver) {
            resolver.markDependency(ITEM_ID);
            resolver.markDependency(BLOCK_ID);
        }

        @Override
        public class_10439 method_65587(class_10440 context) {
            class_7775 baker = context.comp_3390();
            class_10819 itemModel = baker.method_45872(ITEM_ID);
            class_10419 itemTextures = itemModel.method_68045();
            List<class_777> itemQuads = itemModel.method_68034(itemTextures, baker, class_1086.field_5350).method_68048();
            class_10809 settings = class_10809.method_68001(baker, itemModel, itemTextures);
            class_10819 blockModel = baker.method_45872(BLOCK_ID);
            List<class_777> blockQuads = blockModel.method_68034(blockModel.method_68045(), baker, class_1086.field_5350).method_68048();
            return new CardboardSwordModel(itemQuads, blockQuads, settings);
        }
    }
}

==> create-fly-1.21.11-pre1-6.0.8-1-sources.jar: com/zurrtum/create/client/infrastructure/model/CardboardSwordModel.java <==
package com.zurrtum.create.client.infrastructure.model;

import com.google.common.base.Suppliers;
import com.mojang.serialization.MapCodec;
import net.minecraft.class_10419;
import net.minecraft.class_10430;
import net.minecraft.class_10439;
import net.minecraft.class_10442;
import net.minecraft.class_10444;
import net.minecraft.class_10809;
import net.minecraft.class_10819;
import net.minecraft.class_1086;
import net.minecraft.class_11566;
import net.minecraft.class_1799;
import net.minecraft.class_1921;
import net.minecraft.class_2960;
import net.minecraft.class_4722;
import net.minecraft.class_638;
import net.minecraft.class_777;
import net.minecraft.class_7775;
import net.minecraft.class_811;
import net.minecraft.client.renderer.item.*;
import org.jetbrains.annotations.Nullable;
import org.joml.Vector3fc;

import java.util.List;
import java.util.function.Supplier;

import static com.zurrtum.create.Create.MOD_ID;

public class CardboardSwordModel implements class_10439 {
    public static final class_2960 ID = class_2960.method_60655(MOD_ID, "model/cardboard_sword");
    public static final class_2960 ITEM_ID = class_2960.method_60655(MOD_ID, "item/cardboard_sword/item");
    public static final class_2960 BLOCK_ID = class_2960.method_60655(MOD_ID, "item/cardboard_sword/item_in_hand");

    private final class_1921 layer = class_4722.method_29382();
    private final List<class_777> itemQuads;
    private final Supplier<Vector3fc[]> itemVector;
    private final List<class_777> blockQuads;
    private final Supplier<Vector3fc[]> blockVector;
    private final class_10809 settings;

    public CardboardSwordModel(List<class_777> item, List<class_777> block, class_10809 settings) {
        itemQuads = item;
        itemVector = Suppliers.memoize(() -> class_10430.method_67990(itemQuads));
        blockQuads = block;
        blockVector = Suppliers.memoize(() -> class_10430.method_67990(blockQuads));
        this.settings = settings;
    }

    @Override
    public void method_65584(
        class_10444 state,
        class_1799 stack,
        class_10442 resolver,
        class_811 displayContext,
        @Nullable class_638 world,
        @Nullable class_11566 user,
        int seed
    ) {
        state.method_70946(this);
        if (displayContext == class_811.field_4317) {
            update(state, displayContext, itemQuads, settings, itemVector);
        } else {
            update(state, displayContext, blockQuads, settings, blockVector);
        }
    }

    private void update(
        class_10444 state,
        class_811 displayContext,
        List<class_777> quads,
        class_10809 settings,
        Supplier<Vector3fc[]> vector
    ) {
        class_10444.class_10446 layerRenderState = state.method_65601();
        layerRenderState.method_67992(layer);
        layerRenderState.method_67995(vector);
        settings.method_68000(layerRenderState, displayContext);
        layerRenderState.method_67997().addAll(quads);
    }

    public static class Unbaked implements class_10439.class_10441 {
        public static final MapCodec<com.zurrtum.create.client.infrastructure.model.CardboardSwordModel.Unbaked> CODEC = MapCodec.unit(com.zurrtum.create.client.infrastructure.model.CardboardSwordModel.Unbaked::new);

        @Override
        public MapCodec<com.zurrtum.create.client.infrastructure.model.CardboardSwordModel.Unbaked> method_65585() {
            return CODEC;
        }

        @Override
        public void method_62326(class_10103 resolver) {
            resolver.markDependency(ITEM_ID);
            resolver.markDependency(BLOCK_ID);
        }

        @Override
        public class_10439 method_65587(class_10440 context) {
            class_7775 baker = context.comp_3390();
            class_10819 itemModel = baker.method_45872(ITEM_ID);
            class_10419 itemTextures = itemModel.method_68045();
            List<class_777> itemQuads = itemModel.method_68034(itemTextures, baker, class_1086.field_63619).method_68048();
            class_10809 settings = class_10809.method_68001(baker, itemModel, itemTextures);
            class_10819 blockModel = baker.method_45872(BLOCK_ID);
            List<class_777> blockQuads = blockModel.method_68034(blockModel.method_68045(), baker, class_1086.field_63619).method_68048();
            return new CardboardSwordModel(itemQuads, blockQuads, settings);
        }
    }
}
